==> nextcloud-app-mail-5.1.2-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/he.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "הודעה מוטמעת %s",
    "Important mail" : "דוא״ל חשוב",
    "No message found yet" : "לא נמצאו הודעות עדיין",
    "Set up an account" : "הגדרת חשבון",
    "Unread mail" : "דוא״ל שלא נקרא",
    "Important" : "חשוב",
    "Work" : "עבודה",
    "Personal" : "אישי",
    "To Do" : "מטלות",
    "Later" : "אחר כך",
    "Mail" : "דואר",
    "Mails" : "פריטי דוא״ל",
    "💌 A mail app for Nextcloud" : "💌 יישומון דוא״ל ל־Nextcloud",
    "Drafts are saved in:" : "הטיוטות נשמרות תחת:",
    "Sent messages are saved in:" : "ההודעות שנשלחות נשמרות תחת:",
    "Deleted messages are moved in:" : "הודעות שנמחקו מועברות אל:",
    "Connecting" : "מתבצע חיבור",
    "Save" : "שמור",
    "Connect" : "התחברות",
    "Password required" : "נדרשת ססמה",
    "Auto" : "אוטומטי",
    "Name" : "שם",
    "Mail address" : "כתובת דוא״ל",
    "Password" : "ססמה",
    "Manual" : "ידני",
    "IMAP Settings" : "הגדרות IMAP",
    "IMAP Host" : "מארח IMAP",
    "IMAP Security" : "אבטחת IMAP",
    "None" : "ללא",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "פתחת IMAP",
    "IMAP User" : "משתמש IMAP",
    "IMAP Password" : "ססמת IMAP",
    "SMTP Settings" : "הגדרות SMTP",
    "SMTP Host" : "מארח SMTP",
    "SMTP Security" : "אבטחת SMTP",
    "SMTP Port" : "פתחת SMTP",
    "SMTP User" : "משתמש SMTP",
    "SMTP Password" : "ססמת SMTP",
    "Account settings" : "הגדרות חשבון",
    "Aliases" : "כינויים",
    "Signature" : "חתימה",
    "A signature is added to the text of new messages and replies." : "נוספה חתימה לטקסט של הודעות חדשות ותגובות.",
    "Writing mode" : "מצב כתיבה",
    "Preferred writing mode for new messages and replies." : "מצב כתיבה מועדף להודעות חדשות ולתגובות.",
    "Default folders" : "תיקיות בררת מחדל",
    "Mail server" : "שרת דוא״ל",
    "Go back" : "חזרה",
    "Change name" : "החלפת שם",
    "Email address" : "כתובת דוא״ל",
    "Add alias" : "הוספת כינוי",
    "Cancel" : "ביטול",
    "Add mail account" : "הוספת חשבון דוא״ל",
    "General" : "כללי",
    "Sorting" : "מיון",
    "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
    "Register as application for mail links" : "רישום כיישום לטיפול בקישורי דוא״ל (mailto)",
    "Register" : "רישום",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
    "Trusted senders" : "שולחים מהימנים",
    "About" : "אודות",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "Compose new message" : "כתיבת הודעה חדשה",
    "Newer message" : "הודעה חדשה יותר",
    "Older message" : "הודעה ישנה יותר",
    "Toggle star" : "החלפת מצב כוכב",
    "Toggle unread" : "החלפת מצב קריאה",
    "Archive" : "לארכיון",
    "Delete" : "מחיקה",
    "Search" : "חיפוש",
    "Send" : "שליחה",
    "Refresh" : "רענון",
    "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
    "From" : "מאת",
    "Select account" : "בחר חשבון",
    "To" : "אל",
    "Contact or email address …" : "איש קשר או כתובת דוא״ל…",
    "Cc" : "עותק",
    "Bcc" : "עותק נסתר",
    "Subject" : "נושא",
    "Subject …" : "נושא…",
    "This message came from a noreply address so your reply will probably not be read." : "הודעה זו הגיעה מכתובת שאינה מיועדת למענה (noreply) ולכן כנראה שהתגובה שלך לא תיקרא.",
    "The following recipients do not have a PGP key: {recipients}." : "לנמענים הבאים אין מפתח PGP‏: {recipients}.",
    "Write message …" : "כתיבת הודעה…",
    "Saving draft …" : "הטיוטה נשמרת…",
    "Draft saved" : "הטיוטה נשמרה",
    "Enable formatting" : "הפעלת עיצוב",
    "Upload attachment" : "העלאת קובץ מצורף",
    "Add attachment from Files" : "הוספת קובץ מצורף מהקבצים",
    "Request a read receipt" : "בקשת אישור קריאה",
    "Encrypt message with Mailvelope" : "הצפנת הודעה עם Mailvelope",
    "Enter a date" : "נא למלא תאריך",
    "Choose" : "בחר",
    "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
    "Choose a file to share as a link" : "נא לבחור קובץ לשיתוף כקישור",
    "Confirm" : "אימות",
    "Plain text" : "טקסט פשוט",
    "Rich text" : "טקסט עשיר",
    "No messages in this mailbox" : "אין הודעות בתיבת הדוא״ל הזאת",
    "No messages" : "אין הודעות",
    "Blind copy recipients only" : "נמענים נסתרים בלבד",
    "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
    "Could not delete message" : "לא ניתן למחוק הודעה",
    "Draft: " : "טיוטה:",
    "Unfavorite" : "ביטול כמועדף",
    "Favorite" : "סימון כמועדף",
    "Read" : "קריאה",
    "Mark not spam" : "לסמן שזה לא ספאם",
    "Mark as spam" : "לסמן כספאם",
    "Edit tags" : "עריכת תגיות",
    "Move thread" : "העברת שרשור",
    "Delete thread" : "מחיקת שרשור",
    "More actions" : "פעולות נוספות",
    "Back" : "חזרה",
    "Edit as new message" : "עריכה כהודעה חדשה",
    "Create event" : "יצירת אירוע",
    "Load more" : "לטעון עוד",
    "_Mark {number} unread_::_Mark {number} unread_" : ["סימון {number} שלא נקראה","סימון {number} שלא נקראו","סימון {number} שלא נקראו"],
    "Report this bug" : "דיווח על התקלה הזו",
    "Could not create event" : "לא ניתן ליצור אירוע",
    "All day" : "כל היום",
    "Description" : "תיאור",
    "Create" : "יצירה",
    "Select" : "בחירה",
    "Comment" : "הערה",
    "Accept" : "אשר",
    "Decline" : "דחייה",
    "individual" : "יחיד",
    "domain" : "שם תחום",
    "Remove" : "הסרה",
    "email" : "דוא״ל",
    "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
    "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
    "Important info" : "מידע חשוב",
    "Other" : "אחר",
    "Forward" : "העברה",
    "Translate" : "תרגום",
    "View source" : "הצגת המקור",
    "Unnamed" : "ללא שם",
    "Embedded message" : "הודעה מוטמעת",
    "Choose a folder to store the attachment in" : "יש לבחור תיקייה לשמירת הקובץ המצורף",
    "Import into calendar" : "ייבוא ליומן",
    "Download attachment" : "הורדת קובץ מצורף",
    "Save to Files" : "שמירה לקבצים",
    "Choose a folder to store the attachments in" : "נא לבחור תיקייה לאחסן בה את הקבצים המצורפים",
    "Save all to Files" : "שמירת הכו לקבצים",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "הודעה זו מוצפנת עם PGP. יש להתקין את Mailvelope כדי לפענח אותה.",
    "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
    "Message frame" : "מסגרת הודעה",
    "Move" : "העברה",
    "Loading …" : "בטעינה",
    "Not supported by the server" : "לא נתמך על ידי השרת",
    "Remove account" : "הסרת חשבון",
    "Remove {email}" : "להסיר את {email}",
    "Quota" : "מכיסה",
    "Add mailbox" : "הוספת תיבת דוא״ל",
    "Saving" : "שמירה",
    "Move down" : "להוריד למטה",
    "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
    "Collapse mailboxes" : "צמצום תיבות דוא״ל",
    "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
    "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
    "Delete mailbox" : "מחיקת תיבת דוא״ל",
    "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
    "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
    "Mark all as read" : "סימון הכול כנקרא",
    "Mark all messages of this mailbox as read" : "סימון כל ההודעות בתיבת הדוא״ל הזו כנקראו",
    "Add submailbox" : "הוספת תת־תיבת דוא״ל",
    "Rename" : "שינוי שם",
    "Clear cache" : "פינוי מטמון",
    "Clear locally cached data, in case there are issues with synchronization." : "פינוי הנתונים שמאוחסנים מקומית במטמון, במקרה שיש תקלות בסנכרון.",
    "Sync in background" : "סנכרון ברקע",
    "New message" : "הודעה חדשה",
    "Reply" : "תגובה",
    "Error sending your message" : "שליחת ההודעה שלך נכשלה",
    "Retry" : "ניסיון חוזר",
    "Message" : "הודעה",
    "Oh Snap!" : "שוד ושבר!",
    "Copy to clipboard" : "העתקה ללוח הגזירים",
    "Add" : "הוספה",
    "Show less" : "להציג פחות",
    "Show more" : "להציג יותר",
    "Clear" : "פינוי",
    "Close" : "סגירה",
    "Body" : "גוף",
    "Date" : "תאריך",
    "Tags" : "תגיות",
    "Select tags" : "בחירת תגיות",
    "Custom" : "מותאם אישית",
    "Signature …" : "חתימה…",
    "Save signature" : "שמירת החתימה",
    "Tag already exists" : "תגית כבר קיימת",
    "An error occurred, unable to create the tag." : "אירעה שגיאה, לא ניתן ליצור את התגית.",
    "Add tag" : "הוספת תגית",
    "Saving tag …" : "התגית נשמרת…",
    "Could not load your message thread" : "לא ניתן לטעון את שרשור ההודעות שלך",
    "Not found" : "לא נמצא",
    "Reply to sender only" : "להגיב לשולח בלבד",
    "Mark as unread" : "סימון כלא נקרא",
    "Mark as read" : "סימון כנקרא",
    "Message source" : "מקור ההודעה",
    "Could not remove trusted sender {sender}" : "לא ניתן להסיר את השולח המאומת {sender}",
    "No senders are trusted at the moment." : "אין שולחים מהימנים כרגע.",
    "Untitled event" : "אירוע ללא כותרת",
    "(organizer)" : "(מארגן)",
    "Import into {calendar}" : "ייבוא לתוך {calendar}",
    "Event imported into {calendar}" : "האירוע ייובא לתוך {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "טיסה {flightNr} מ{depAirport} אל {arrAirport}",
    "Airplane" : "מטוב",
    "Reservation {id}" : "הזמנה {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} מ־{depStation} אל {arrStation}",
    "Train from {depStation} to {arrStation}" : "רכבת מ־{depStation} אל {arrStation}",
    "Train" : "רכבת",
    "Actions" : "פעולות",
    "Priority" : "עדיפות",
    "Mail app" : "יישומון דוא״ל",
    "The mail app allows users to read mails on their IMAP accounts." : "יישומון הדוא״ל מאפשר למשתמשים לקרוא הודעות דוא״ל בחשבונות ה־IMAP שלהם.",
    "Reset" : "איפוס",
    "Client ID" : "מזהה לקו",
    "Client secret" : "סוד לקוח",
    "Email: {email}" : "דוא״ל: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP:‏ {user} על גבי ‎{host}:{port}‎ (הצפנת {ssl})",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP:‏ {user} על גבי ‎{host}:{port}‎ (הצפנת {ssl})",
    "Email address template" : "תבנית כתובת דוא״ל",
    "IMAP" : "IMAP",
    "User" : "משתמש",
    "Host" : "מארח",
    "Port" : "פתחה",
    "SMTP" : "SMTP",
    "Save Config" : "שמירת הגדרות",
    "With the settings above, the app will create account settings in the following way:" : "עם ההגדרות שלהלן, היישומון יצור הגדרות חשבון באופן הבא:",
    "E-mail address" : "כתובת דוא״ל",
    "Valid until" : "בתוקף עד",
    "Certificate" : "אישור",
    "Submit" : "שליחה",
    "Account connected" : "חשבון מחובר",
    "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
    "All" : "הכול",
    "Drafts" : "טיוטות",
    "Favorites" : "מועדפים",
    "Priority inbox" : "תיבת דואר נכנס בעדיפות",
    "All inboxes" : "כל תיבות דואר נכנס",
    "Inbox" : "דואר נכנס",
    "Junk" : "דואר זבל",
    "Sent" : "נשלח",
    "Trash" : "פח אשפה",
    "Error while sharing file" : "שגיאה בשיתוף הקובץ",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["הודעה חדשה \nמאת {from}","2 הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}"],
    "Nextcloud Mail" : "דוא״ל Nextcloud",
    "Attachments were not copied. Please add them manually." : "הקבצים המצורפים לא הועתקו. נא להוסיף אותם ידנית.",
    "Message sent" : "הודעה נשלחה",
    "Could not load {tag}{name}{endtag}" : "לא ניתן לטעון את {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "אירעה שגיאה בטעינה של {tag}{name}{endtag}",
    "Could not load your message" : "לא ניתן לטעון את ההודעה שלך",
    "Could not load the desired message" : "לא ניתן לטעון את ההודעה המבוקשת",
    "Could not load the message" : "לא ניתן לטעון את ההודעה",
    "Error loading message" : "שגיאה בהעלאת הודעה",
    "Forwarding to %s" : "מועבר אל %s",
    "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
    "Redirect" : "הפנייה",
    "The link leads to %s" : "הקישור מוביל אל %s",
    "Continue to %s" : "ממשיך אל %s"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");

==> nextcloud-app-mail-5.1.4-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/he.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "הודעה מוטמעת %s",
    "Important mail" : "דוא״ל חשוב",
    "No message found yet" : "לא נמצאו הודעות עדיין",
    "Set up an account" : "הגדרת חשבון",
    "Unread mail" : "דוא״ל שלא נקרא",
    "Important" : "חשוב",
    "Work" : "עבודה",
    "Personal" : "אישי",
    "To Do" : "מטלות",
    "Later" : "אחר כך",
    "Mail" : "דואר",
    "Mails" : "פריטי דוא״ל",
    "💌 A mail app for Nextcloud" : "💌 יישומון דוא״ל ל־Nextcloud",
    "Drafts are saved in:" : "הטיוטות נשמרות תחת:",
    "Sent messages are saved in:" : "ההודעות שנשלחות נשמרות תחת:",
    "Deleted messages are moved in:" : "הודעות שנמחקו מועברות אל:",
    "Connecting" : "מתבצע חיבור",
    "Save" : "שמור",
    "Connect" : "התחברות",
    "Password required" : "נדרשת ססמה",
    "Auto" : "אוטומטי",
    "Name" : "שם",
    "Mail address" : "כתובת דוא״ל",
    "Password" : "ססמה",
    "Manual" : "ידני",
    "IMAP Settings" : "הגדרות IMAP",
    "IMAP Host" : "מארח IMAP",
    "IMAP Security" : "אבטחת IMAP",
    "None" : "ללא",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "פתחת IMAP",
    "IMAP User" : "משתמש IMAP",
    "IMAP Password" : "ססמת IMAP",
    "SMTP Settings" : "הגדרות SMTP",
    "SMTP Host" : "מארח SMTP",
    "SMTP Security" : "אבטחת SMTP",
    "SMTP Port" : "פתחת SMTP",
    "SMTP User" : "משתמש SMTP",
    "SMTP Password" : "ססמת SMTP",
    "Account settings" : "הגדרות חשבון",
    "Aliases" : "כינויים",
    "Signature" : "חתימה",
    "A signature is added to the text of new messages and replies." : "נוספה חתימה לטקסט של הודעות חדשות ותגובות.",
    "Writing mode" : "מצב כתיבה",
    "Preferred writing mode for new messages and replies." : "מצב כתיבה מועדף להודעות חדשות ולתגובות.",
    "Default folders" : "תיקיות בררת מחדל",
    "Mail server" : "שרת דוא״ל",
    "Go back" : "חזרה",
    "Change name" : "החלפת שם",
    "Email address" : "כתובת דוא״ל",
    "Add alias" : "הוספת כינוי",
    "Cancel" : "ביטול",
    "Add mail account" : "הוספת חשבון דוא״ל",
    "General" : "כללי",
    "Sorting" : "מיון",
    "Use Gravatar and favicon avatars" : "להשתמש בסמלים של Gravatar ושל favicon",
    "Register as application for mail links" : "רישום כיישום לטיפול בקישורי דוא״ל (mailto)",
    "Register" : "רישום",
    "Allow the app to collect data about your interactions. Based on this data, the app will adapt to your preferences. The data will only be stored locally." : "לאפשר ליישומן לאסוף נתונים על אופן השימוש שלך. על בסיס המידע הזה, היישומון יתאים את עצמו להעדפות שלך. הנתונים יישמרו מקומית בלבד.",
    "Trusted senders" : "שולחים מהימנים",
    "About" : "אודות",
    "Keyboard shortcuts" : "קיצורי מקלדת",
    "Compose new message" : "כתיבת הודעה חדשה",
    "Newer message" : "הודעה חדשה יותר",
    "Older message" : "הודעה ישנה יותר",
    "Toggle star" : "החלפת מצב כוכב",
    "Toggle unread" : "החלפת מצב קריאה",
    "Archive" : "לארכיון",
    "Delete" : "מחיקה",
    "Search" : "חיפוש",
    "Send" : "שליחה",
    "Refresh" : "רענון",
    "Message {id} could not be found" : "לא ניתן למצוא את הודעה {id}",
    "From" : "מאת",
    "Select account" : "בחר חשבון",
    "To" : "אל",
    "Contact or email address …" : "איש קשר או כתובת דוא״ל…",
    "Cc" : "עותק",
    "Bcc" : "עותק נסתר",
    "Subject" : "נושא",
    "Subject …" : "נושא…",
    "This message came from a noreply address so your reply will probably not be read." : "הודעה זו הגיעה מכתובת שאינה מיועדת למענה (noreply) ולכן כנראה שהתגובה שלך לא תיקרא.",
    "The following recipients do not have a PGP key: {recipients}." : "לנמענים הבאים אין מפתח PGP‏: {recipients}.",
    "Write message …" : "כתיבת הודעה…",
    "Saving draft …" : "הטיוטה נשמרת…",
    "Draft saved" : "הטיוטה נשמרה",
    "Enable formatting" : "הפעלת עיצוב",
    "Upload attachment" : "העלאת קובץ מצורף",
    "Add attachment from Files" : "הוספת קובץ מצורף מהקבצים",
    "Request a read receipt" : "בקשת אישור קריאה",
    "Encrypt message with Mailvelope" : "הצפנת הודעה עם Mailvelope",
    "Enter a date" : "נא למלא תאריך",
    "Choose" : "בחר",
    "Choose a file to add as attachment" : "בחירת קובץ להוספה כקובץ מצורף",
    "Choose a file to share as a link" : "נא לבחור קובץ לשיתוף כקישור",
    "Confirm" : "אימות",
    "Plain text" : "טקסט פשוט",
    "Rich text" : "טקסט עשיר",
    "No messages in this mailbox" : "אין הודעות בתיבת הדוא״ל הזאת",
    "No messages" : "אין הודעות",
    "Blind copy recipients only" : "נמענים נסתרים בלבד",
    "No trash mailbox configured" : "לא הוגדרה תיבת דוא״ל לאשפה",
    "Could not delete message" : "לא ניתן למחוק הודעה",
    "Draft: " : "טיוטה:",
    "Unfavorite" : "ביטול כמועדף",
    "Favorite" : "סימון כמועדף",
    "Read" : "קריאה",
    "Mark not spam" : "לסמן שזה לא ספאם",
    "Mark as spam" : "לסמן כספאם",
    "Edit tags" : "עריכת תגיות",
    "Move thread" : "העברת שרשור",
    "Delete thread" : "מחיקת שרשור",
    "More actions" : "פעולות נוספות",
    "Back" : "חזרה",
    "Edit as new message" : "עריכה כהודעה חדשה",
    "Create event" : "יצירת אירוע",
    "Load more" : "לטעון עוד",
    "_Mark {number} unread_::_Mark {number} unread_" : ["סימון {number} שלא נקראה","סימון {number} שלא נקראו","סימון {number} שלא נקראו"],
    "Report this bug" : "דיווח על התקלה הזו",
    "Could not create event" : "לא ניתן ליצור אירוע",
    "All day" : "כל היום",
    "Description" : "תיאור",
    "Create" : "יצירה",
    "Select" : "בחירה",
    "Comment" : "הערה",
    "Accept" : "אשר",
    "Decline" : "דחייה",
    "individual" : "יחיד",
    "domain" : "שם תחום",
    "Remove" : "הסרה",
    "email" : "דוא״ל",
    "Itinerary for {type} is not supported yet" : "פירוט המסלול {type} אינו נתמך עדיין",
    "Could not open mailbox" : "לא ניתן לפתוח את תיבת הדואר",
    "Indexing your messages. This can take a bit longer for larger mailboxes." : "ההודעות שלך מסודרות באינדקס. פעולה זו עשויה לארוך זמן מה בתיבות דואר גדולות.",
    "Important info" : "מידע חשוב",
    "Other" : "אחר",
    "Forward" : "העברה",
    "Translate" : "תרגום",
    "View source" : "הצגת המקור",
    "Unnamed" : "ללא שם",
    "Embedded message" : "הודעה מוטמעת",
    "Choose a folder to store the attachment in" : "יש לבחור תיקייה לשמירת הקובץ המצורף",
    "Import into calendar" : "ייבוא ליומן",
    "Download attachment" : "הורדת קובץ מצורף",
    "Save to Files" : "שמירה לקבצים",
    "Choose a folder to store the attachments in" : "נא לבחור תיקייה לאחסן בה את הקבצים המצורפים",
    "Save all to Files" : "שמירת הכו לקבצים",
    "This message is encrypted with PGP. Install Mailvelope to decrypt it." : "הודעה זו מוצפנת עם PGP. יש להתקין את Mailvelope כדי לפענח אותה.",
    "The images have been blocked to protect your privacy." : "התמונות נחסמו כדי להגן על הפרטיות שלך",
    "Message frame" : "מסגרת הודעה",
    "Move" : "העברה",
    "Loading …" : "בטעינה",
    "Not supported by the server" : "לא נתמך על ידי השרת",
    "Remove account" : "הסרת חשבון",
    "Remove {email}" : "להסיר את {email}",
    "Quota" : "מכיסה",
    "Add mailbox" : "הוספת תיבת דוא״ל",
    "Saving" : "שמירה",
    "Move down" : "להוריד למטה",
    "Show all mailboxes" : "הצגת כל תיבות הדוא״ל",
    "Collapse mailboxes" : "צמצום תיבות דוא״ל",
    "_{total} message_::_{total} messages_" : ["הודעה אחת","{total} הודעות","{total} הודעות"],
    "_{unread} unread of {total}_::_{unread} unread of {total}_" : ["אחת לא נקראה מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}","{unread} לא נקראו מתוך {total}"],
    "The mailbox and all messages in it will be deleted." : "תיבת הדוא״ל על כל ההודעות שבה תימחק.",
    "Delete mailbox" : "מחיקת תיבת דוא״ל",
    "Delete mailbox {name}" : "מחיקת תיבת הדוא״ל {name}",
    "An error occurred, unable to rename the mailbox." : "אירעה שגיאה, לא ניתן לשנות את שם תיבת הדוא״ל.",
    "Mark all as read" : "סימון הכול כנקרא",
    "Mark all messages of this mailbox as read" : "סימון כל ההודעות בתיבת הדוא״ל הזו כנקראו",
    "Add submailbox" : "הוספת תת־תיבת דוא״ל",
    "Rename" : "שינוי שם",
    "Clear cache" : "פינוי מטמון",
    "Clear locally cached data, in case there are issues with synchronization." : "פינוי הנתונים שמאוחסנים מקומית במטמון, במקרה שיש תקלות בסנכרון.",
    "Sync in background" : "סנכרון ברקע",
    "New message" : "הודעה חדשה",
    "Reply" : "תגובה",
    "Error sending your message" : "שליחת ההודעה שלך נכשלה",
    "Retry" : "ניסיון חוזר",
    "Message" : "הודעה",
    "Oh Snap!" : "שוד ושבר!",
    "Copy to clipboard" : "העתקה ללוח הגזירים",
    "Add" : "הוספה",
    "Show less" : "להציג פחות",
    "Show more" : "להציג יותר",
    "Clear" : "פינוי",
    "Close" : "סגירה",
    "Body" : "גוף",
    "Date" : "תאריך",
    "Tags" : "תגיות",
    "Select tags" : "בחירת תגיות",
    "Custom" : "מותאם אישית",
    "Signature …" : "חתימה…",
    "Save signature" : "שמירת החתימה",
    "Tag already exists" : "תגית כבר קיימת",
    "An error occurred, unable to create the tag." : "אירעה שגיאה, לא ניתן ליצור את התגית.",
    "Add tag" : "הוספת תגית",
    "Saving tag …" : "התגית נשמרת…",
    "Could not load your message thread" : "לא ניתן לטעון את שרשור ההודעות שלך",
    "Not found" : "לא נמצא",
    "Reply to sender only" : "להגיב לשולח בלבד",
    "Mark as unread" : "סימון כלא נקרא",
    "Mark as read" : "סימון כנקרא",
    "Message source" : "מקור ההודעה",
    "Could not remove trusted sender {sender}" : "לא ניתן להסיר את השולח המאומת {sender}",
    "No senders are trusted at the moment." : "אין שולחים מהימנים כרגע.",
    "Untitled event" : "אירוע ללא כותרת",
    "(organizer)" : "(מארגן)",
    "Import into {calendar}" : "ייבוא לתוך {calendar}",
    "Event imported into {calendar}" : "האירוע ייובא לתוך {calendar}",
    "Flight {flightNr} from {depAirport} to {arrAirport}" : "טיסה {flightNr} מ{depAirport} אל {arrAirport}",
    "Airplane" : "מטוב",
    "Reservation {id}" : "הזמנה {id}",
    "{trainNr} from {depStation} to {arrStation}" : "{trainNr} מ־{depStation} אל {arrStation}",
    "Train from {depStation} to {arrStation}" : "רכבת מ־{depStation} אל {arrStation}",
    "Train" : "רכבת",
    "matches" : "תואם",
    "Priority" : "עדיפות",
    "Mail app" : "יישומון דוא״ל",
    "The mail app allows users to read mails on their IMAP accounts." : "יישומון הדוא״ל מאפשר למשתמשים לקרוא הודעות דוא״ל בחשבונות ה־IMAP שלהם.",
    "Reset" : "איפוס",
    "Client ID" : "מזהה לקו",
    "Client secret" : "סוד לקוח",
    "Email: {email}" : "דוא״ל: {email}",
    "IMAP: {user} on {host}:{port} ({ssl} encryption)" : "IMAP:‏ {user} על גבי ‎{host}:{port}‎ (הצפנת {ssl})",
    "SMTP: {user} on {host}:{port} ({ssl} encryption)" : "SMTP:‏ {user} על גבי ‎{host}:{port}‎ (הצפנת {ssl})",
    "Email address template" : "תבנית כתובת דוא״ל",
    "IMAP" : "IMAP",
    "User" : "משתמש",
    "Host" : "מארח",
    "Port" : "פתחה",
    "SMTP" : "SMTP",
    "Save Config" : "שמירת הגדרות",
    "With the settings above, the app will create account settings in the following way:" : "עם ההגדרות שלהלן, היישומון יצור הגדרות חשבון באופן הבא:",
    "E-mail address" : "כתובת דוא״ל",
    "Valid until" : "בתוקף עד",
    "Certificate" : "אישור",
    "Submit" : "שליחה",
    "Account connected" : "חשבון מחובר",
    "Connect your mail account" : "התחברות לחשבון הדוא״ל שלך",
    "All" : "הכול",
    "Drafts" : "טיוטות",
    "Favorites" : "מועדפים",
    "Priority inbox" : "תיבת דואר נכנס בעדיפות",
    "All inboxes" : "כל תיבות דואר נכנס",
    "Inbox" : "דואר נכנס",
    "Junk" : "דואר זבל",
    "Sent" : "נשלח",
    "Trash" : "פח אשפה",
    "Error while sharing file" : "שגיאה בשיתוף הקובץ",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["הודעה חדשה \nמאת {from}","2 הודעות חדשות \nמאת {from}","%n הודעות חדשות \nמאת {from}"],
    "Nextcloud Mail" : "דוא״ל Nextcloud",
    "Attachments were not copied. Please add them manually." : "הקבצים המצורפים לא הועתקו. נא להוסיף אותם ידנית.",
    "Message sent" : "הודעה נשלחה",
    "Could not load {tag}{name}{endtag}" : "לא ניתן לטעון את {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "אירעה שגיאה בטעינה של {tag}{name}{endtag}",
    "Could not load your message" : "לא ניתן לטעון את ההודעה שלך",
    "Could not load the desired message" : "לא ניתן לטעון את ההודעה המבוקשת",
    "Could not load the message" : "לא ניתן לטעון את ההודעה",
    "Error loading message" : "שגיאה בהעלאת הודעה",
    "Forwarding to %s" : "מועבר אל %s",
    "Click here if you are not automatically redirected within the next few seconds." : "יש ללחוץ כאן אם לא הועברת אוטומטית בשניות הקרובות.",
    "Redirect" : "הפנייה",
    "The link leads to %s" : "הקישור מוביל אל %s",
    "Continue to %s" : "ממשיך אל %s",
    "Actions" : "פעולות"
},
"nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
